# Fair Use Disclaimer

The data included in this folder are provided for research purposes only. The use of these data is believed to be **fair use** under copyright law because:

1. The data are used for **non-commercial research**.
2. The extracted word lists are **small portions** of the original works and do not substitute for them.
3. The use of the data **adds new meaning and context**, contributing to academic and scientific inquiry.
4. The inclusion of the data **does not harm the market value** of the original works.

If you are the copyright owner and believe that this use does not qualify as fair use, please contact us to discuss appropriate actions.

Contact: [GitHub Issues](https://github.com/matus-pikuliak/genderbench/issues)
